@@ -65,7 +65,7 @@ bool KonsoleKalendar::importCalendar()
 
 bool KonsoleKalendar::printCalendarList()
 {
-    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
+    auto job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
     const QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar") << KCalendarCore::Event::eventMimeType()
                                                 << KCalendarCore::Todo::todoMimeType() << KCalendarCore::Journal::journalMimeType();
     job->fetchScope().setContentMimeTypes(mimeTypes);
@@ -89,7 +89,7 @@ bool KonsoleKalendar::printCalendarList()
             const QStringList contentMimeTypes = collection.contentMimeTypes();
             auto collectionMimeTypeSet = QSet<QString>(contentMimeTypes.begin(), contentMimeTypes.end());
 
-            if (!mimeTypeSet.intersect(collectionMimeTypeSet).isEmpty()) {
+            if (mimeTypeSet.intersects(collectionMimeTypeSet)) {
                 QString colId = QString::number(collection.id()).leftJustified(6, QLatin1Char(' '));
                 colId += QLatin1String("- ");
 
@@ -109,7 +109,7 @@ bool KonsoleKalendar::printCalendarList()
 bool KonsoleKalendar::createAkonadiResource(const QString &icalFileUri)
 {
     Akonadi::AgentType type = Akonadi::AgentManager::self()->type(QStringLiteral("akonadi_ical_resource"));
-    Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(type);
+    auto job = new Akonadi::AgentInstanceCreateJob(type);
     QEventLoop loop;
     QObject::connect(job, &Akonadi::CollectionFetchJob::result, &loop, &QEventLoop::quit);
     job->start();
@@ -253,7 +253,7 @@ bool KonsoleKalendar::showInstance()
                                                  << "HTML view all events sorted list";
                     // sort the events for this date by start date
                     // in order to determine the date range.
-                    Event::List *events = new Event::List(calendar->rawEvents(EventSortStartDate, SortDirectionAscending));
+                    auto events = new Event::List(calendar->rawEvents(EventSortStartDate, SortDirectionAscending));
                     firstdate = events->first()->dtStart().date();
                     lastdate = events->last()->dtStart().date();
                 } else if (m_variables->isUID()) {
@@ -304,15 +304,10 @@ bool KonsoleKalendar::showInstance()
                 //         htmlSettings.setTaskAttendees( false );
                 //         htmlSettings.setTaskDueDate( true );
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                htmlSettings.setDateStart(QDateTime(firstdate));
-                htmlSettings.setDateEnd(QDateTime(lastdate));
-#else
                 htmlSettings.setDateStart(QDateTime(firstdate.startOfDay()));
                 htmlSettings.setDateEnd(QDateTime(lastdate.startOfDay()));
-#endif
 
-                KCalUtils::HtmlExport *exp = new KCalUtils::HtmlExport(calendar.data(), &htmlSettings);
+                auto exp = new KCalUtils::HtmlExport(calendar.data(), &htmlSettings);
                 status = exp->save(&ts);
                 delete exp;
             }
